==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S088a1ca5713656359ed3665c293bfc71.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "S76eaa083f88fdd66f6f3f7ac1cd91f27.h"

#include "S57eed6fb2a8ce5b9f949ceebffa654b5.h"

#include "S18fff9cb5ec66ea1b3998c0c6f504bdd.h"
 
#ifdef macintosh
 
#pragma Sdcf15d3851e1b8c3d02afa9e565936b4 off
 
#endif
  void S24167a09269aa22feec4af9cf5d40a1d(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179) 
{  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, NULL, "table_bar_height", 
"tbh", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "max_table_item_length", "mtil", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "max_table_item_rows", "mtir", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "sample_time_units", "stu", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "expand_paths_greater_than", "epgt", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX))); 
 ((S18fff9cb5ec66ea1b3998c0c6f504bdd(S99ca7ef59ba899fc00d32b586b2576c8) *) S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.Sc3809410bc68b6ad7407904a3e598ae9)->push_back(new 
Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "calendar_month_columns", "cmc", new S58aff0477f38707b97c84a6899d13624(0, 1, 12)));  ((S18fff9cb5ec66ea1b3998c0c6f504bdd(S99ca7ef59ba899fc00d32b586b2576c8) 
*) S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.Sc3809410bc68b6ad7407904a3e598ae9)->push_back(new 
Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "first_day_of_week", "fdow", new S58aff0477f38707b97c84a6899d13624(0, 1, 7)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "max_table_bar_length", "mtbl", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S6e140e2f2221b90042fef432e6d282eb, 
NULL, "compact_tables", "ct", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, S78e6221f6393d1356681db398f14ce6d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "use_tables_for_table_bars", "utftb", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, S78e6221f6393d1356681db398f14ce6d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "stretch_bar_unit", "sbu", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S2e73921d23514b94e0ed95cc5f40a3e5, 
NULL, "generate_path_reference_icons", "gpri", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "bar_bottom_color", "bbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "bar_middle_color", "bmc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "bar_top_color", "btc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "html_table_bar_color", "tbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "page_views_table_bar_color", "pvtbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "bandwidth_table_bar_color", "btbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "visitors_table_bar_color", "vtbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "sessions_information_color", "sic", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "bar_unit_image", "bui", new Sd0ab4849fc91062931b627de26bed172(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, NULL, "right_bar_cap_image", 
"rbci", new Sd0ab4849fc91062931b627de26bed172(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "left_bar_cap_image", "lbci", new Sd0ab4849fc91062931b627de26bed172(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Saab9e1de16f38176f86d7a92ba337a8d, Sd6c7d3cb0e6cf388d1d83e983caffdff, NULL, "view_info", "vi", 
new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sa8723206644a15b67e0c18d9bf88639b, 
NULL, "statistics_font", "sf", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
""), new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, ""), new S58aff0477f38707b97c84a6899d13624(0, 
LONG_MIN, LONG_MAX), new S34c8bc3f549bc1db617d4ed83a8481b4(false), new S34c8bc3f549bc1db617d4ed83a8481b4(false), 
new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, ""))); }

==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/S088a1ca5713656359ed3665c293bfc71.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "S76eaa083f88fdd66f6f3f7ac1cd91f27.h"

#include "S57eed6fb2a8ce5b9f949ceebffa654b5.h"

#include "S18fff9cb5ec66ea1b3998c0c6f504bdd.h"
 
#ifdef macintosh
 
#pragma Sdcf15d3851e1b8c3d02afa9e565936b4 off
 
#endif
  void S24167a09269aa22feec4af9cf5d40a1d(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179) 
{  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, NULL, "table_bar_height", 
"tbh", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "max_table_item_length", "mtil", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "max_table_item_rows", "mtir", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "max_filter_menu_length", "mfml", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "sample_time_units", "stu", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "expand_paths_greater_than", "epgt", new S58aff0477f38707b97c84a6899d13624(0, 0, LONG_MAX))); 
 ((S18fff9cb5ec66ea1b3998c0c6f504bdd(S99ca7ef59ba899fc00d32b586b2576c8) *) S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.Sc3809410bc68b6ad7407904a3e598ae9)->push_back(new 
Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "calendar_month_columns", "cmc", new S58aff0477f38707b97c84a6899d13624(0, 1, 12)));  ((S18fff9cb5ec66ea1b3998c0c6f504bdd(S99ca7ef59ba899fc00d32b586b2576c8) 
*) S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.Sc3809410bc68b6ad7407904a3e598ae9)->push_back(new 
Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S6e140e2f2221b90042fef432e6d282eb, 
NULL, "first_day_of_week", "fdow", new S58aff0477f38707b97c84a6899d13624(0, 1, 7)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sde1d215fa045a79a23c8683d72c8f41e, 
NULL, "max_table_bar_length", "mtbl", new S58aff0477f38707b97c84a6899d13624(0, 1, LONG_MAX)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S6e140e2f2221b90042fef432e6d282eb, 
NULL, "compact_tables", "ct", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, S78e6221f6393d1356681db398f14ce6d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "use_tables_for_table_bars", "utftb", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, S78e6221f6393d1356681db398f14ce6d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "stretch_bar_unit", "sbu", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S2e73921d23514b94e0ed95cc5f40a3e5, 
NULL, "generate_path_reference_icons", "gpri", new S34c8bc3f549bc1db617d4ed83a8481b4(false)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "bar_bottom_color", "bbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "bar_middle_color", "bmc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "bar_top_color", "btc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "html_table_bar_color", "tbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "page_views_table_bar_color", "pvtbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "bandwidth_table_bar_color", "btbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "visitors_table_bar_color", "vtbc", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S5f5c74b2be2b3cdb533fed1989d12a7c, 
NULL, "sessions_information_color", "sic", new S58aff0477f38707b97c84a6899d13624(0, 0, 255), new S58aff0477f38707b97c84a6899d13624(0, 
0, 255), new S58aff0477f38707b97c84a6899d13624(0, 0, 255)));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "bar_unit_image", "bui", new Sd0ab4849fc91062931b627de26bed172(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, NULL, "right_bar_cap_image", 
"rbci", new Sd0ab4849fc91062931b627de26bed172(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, S35a4178eeb80f2bf66ce2704e6cd8b07, 
NULL, "left_bar_cap_image", "lbci", new Sd0ab4849fc91062931b627de26bed172(S4d682ec4eed27c53849758bc13b6e179, 
"")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, new Sbe3e989ada99c227c97c9af8c198bf6f(true, 
false, Saab9e1de16f38176f86d7a92ba337a8d, Sd6c7d3cb0e6cf388d1d83e983caffdff, NULL, "view_info", "vi", 
new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, "")));  S1ee8f4d114fcc8468ac71b2b00da4bf4(S4d682ec4eed27c53849758bc13b6e179, 
new Sbe3e989ada99c227c97c9af8c198bf6f(true, false, Saab9e1de16f38176f86d7a92ba337a8d, Sa8723206644a15b67e0c18d9bf88639b, 
NULL, "statistics_font", "sf", new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, 
""), new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, ""), new S58aff0477f38707b97c84a6899d13624(0, 
LONG_MIN, LONG_MAX), new S34c8bc3f549bc1db617d4ed83a8481b4(false), new S34c8bc3f549bc1db617d4ed83a8481b4(false), 
new Sa66884641c1eee0d1eab73a89af79cfc(S4d682ec4eed27c53849758bc13b6e179, ""))); }
